@@ -18,6 +18,14 @@ class Tag:
     def span(children: Union[str, 'Tag', List[Union[str, 'Tag']]]=None):
         return Tag('span', children or [])
 
+    @staticmethod
+    def pre(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("pre", children or [])
+
+    @staticmethod
+    def code(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("code", children or [])
+
     @staticmethod
     def a(children: Union[str, 'Tag', List[Union[str, 'Tag']]]=None):
         return Tag("a", children or [])
@@ -26,6 +34,10 @@ class Tag:
     def ul(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
         return Tag("ul", children or [])
 
+    @staticmethod
+    def ol(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("ol", children or [])
+
     @staticmethod
     def li(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
         return Tag("li", children or [])
@@ -38,6 +50,30 @@ class Tag:
     def p(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
         return Tag("p", children or [])
 
+    @staticmethod
+    def table(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("table", children or [])
+
+    @staticmethod
+    def thead(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("thead", children or [])
+
+    @staticmethod
+    def tbody(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("tbody", children or [])
+
+    @staticmethod
+    def tr(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("tr", children or [])
+
+    @staticmethod
+    def th(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("th", children or [])
+
+    @staticmethod
+    def td(children: Union[str, 'Tag', List[Union[str, 'Tag']]] = None):
+        return Tag("td", children or [])
+
     def css(self, **kwargs):
         for prop, value in kwargs.items():
             result = []
