@@ -40,7 +40,7 @@ class LabExtDataTable {
                 this.tunnel.send_msg(JSON.stringify({ "type": "status", "msg": "init_done" }));
             }, drawCallback: () => {
                 if (this.isInitComplete) {
-                    this.tunnel.send_msg(JSON.stringify({ "type": "status", "msg": "redraw" }));
+                    this.tunnel.send_msg(JSON.stringify({ "type": "status", "msg": "redraw_done" }));
                 }
             } }, this.options));
     }
